<?php
namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\TeknisaCrud;
use Teknisa\SM\Controller\ReplicacaoParceiroController as Replicacao;
use Teknisa\SM\Service\ParceiroNegocioService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

class ParceiroNegocioController extends TeknisaCrud {

    protected $crudService;
    protected $dataSourceName = 'crm_parcnegocio';
    protected $parameterBagColumns = array('IDTPOPERADOR', 'NRREVENDA', 'IDNOMETAG');
    protected $parceiroService;

    public function __construct($crudService, ParameterBag $parameterBag, ParceiroNegocioService $parceiroService, $tagController, Replicacao $replicacao) {
        $this->crudService = $crudService;
        $this->parceiroService = $parceiroService;
        $this->tagController = $tagController;
        $this->replicacao = $replicacao;
        parent::__construct($crudService, $parameterBag);
    }
    
    public function find(DTO\Request\Filter $request,DTO\Response $response) {
        $hasTagFilter = false;
        
        foreach($request->getFilterCriteria()->getConditions() as $filter){
            if($filter['columnName'] === 'IDNOMETAG')
                $hasTagFilter = true;
        }
        if(!$hasTagFilter)
            $request->getFilterCriteria()->addCondition('IDNOMETAG', '=', '');
        parent::find($request, $response);    
    }
    
    public function deleteContato(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $this->parceiroService->deleteContato($row);  
    }
    public function findContato(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName = 'crm_relacionaparc';
        $this->parameterBagColumns = array('P_NRORG');
        parent::find($request, $response);
    }
    
    public function findRelacionamento(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName = 'crm_tiporelaciona';
        $this->parameterBagColumns = array();
        parent::find($request, $response);
    }
    
    public function saveContato(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $parcnegocio = $this->parceiroService->saveContato($row);
            $response->addDataset(new DataSet('columnsToReturn', array("NRPARCNEGOCIO" => $parcnegocio['NRPARCNEGOCIO'], "NRRELACIONAPARC" =>$parcnegocio['NRRELACIONAPARC'])));
            
        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function save(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $nrparcnegocio = $this->parceiroService->saveParceiro($row);
            $row['IDNOMETAG'] = isset($row['IDNOMETAG']) ? $row['IDNOMETAG'] : '';
            $this->tagController->saveOrUpdateTags($nrparcnegocio, $row['IDNOMETAG'], 'PARCNEGOCIO');
            $replicacao = $this->replicacao->replica($nrparcnegocio, $row['CDTIPOPARCPRINCIPAL'], 'PARCEIRO');
            $response->addDataSet(new DataSet("REPLICACAO", array($replicacao)));
            if ($row['__is_new']) {
                $response->addDataset(new DataSet('columnsToReturn', array("NRPARCNEGOCIO" => $nrparcnegocio)));
            }
        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}